package models

import (
	"context"
	"hongze/hongze_wx_listen/global"
	"time"
)

// WechatGroup 微信群表
type WechatGroup struct {
	WechatGroupId   int       `gorm:"primaryKey;column:wechat_group_id;" description:"微信群id"`
	WechatGroupName string    `description:"微信群名"`
	WechatId        string    `description:"微信群标识"`
	Enabled         int8      `description:"1:有效，0:禁用"`
	ModifyTime      time.Time `description:"修改时间"`
	CreateTime      time.Time `description:"发送时间"`
}

func (m *WechatGroup) TableName() string {
	return "wechat_group"
}

// GetListByIdList 通过群id列表获取所有关联的群
func (m *WechatGroup) GetListByIdList(wechatGroupIdList []int) (items []*WechatGroup, err error) {
	err = global.DEFAULT_MYSQL.WithContext(context.TODO()).Model(m).
		Where("wechat_group_id in (?) ", wechatGroupIdList).Find(&items).Error

	return
}

// GetEnabledListByIdList 通过群id列表获取所有关联的激活的群
func (m *WechatGroup) GetEnabledListByIdList(wechatGroupIdList []int) (items []*WechatGroup, err error) {
	err = global.DEFAULT_MYSQL.WithContext(context.TODO()).Model(m).
		Where("wechat_group_id in (?) AND enabled = 1 ", wechatGroupIdList).Find(&items).Error

	return
}

// GetByWxId 通过群id获取的群信息
func (m *WechatGroup) GetByWxId(wxId string) (item *WechatGroup, err error) {
	err = global.DEFAULT_MYSQL.WithContext(context.TODO()).Model(m).
		Where("wechat_id = ? ", wxId).First(&item).Error

	return
}

// GetListByWxIdList 通过群标识列表获取所有关联的群
func (m *WechatGroup) GetListByWxIdList(wechatIdList []string) (items []*WechatGroup, err error) {
	err = global.DEFAULT_MYSQL.WithContext(context.TODO()).Model(m).
		Where("wechat_id in (?) ", wechatIdList).Find(&items).Error

	return
}

// Create 添加记录
func (m *WechatGroup) Create() (err error) {
	err = global.DEFAULT_MYSQL.Create(m).Error

	return
}

// CreateList 批量添加入库
func (m *WechatGroup) CreateList(list []WechatGroup) (err error) {
	err = global.DEFAULT_MYSQL.Create(list).Error

	return
}

// Update 更新对应字段数据
func (m *WechatGroup) Update(updateCols []string) (err error) {
	err = global.DEFAULT_MYSQL.Model(m).Select(updateCols).Updates(*m).Error

	return
}
