package models

import (
	"hongze/hongze_wx_listen/global"
	"time"
)

// ListenWxAppType 小程序的消息类型
var ListenWxAppType = 49

// WechatListenMsgRecord 微信消息监听记录表
type WechatListenMsgRecord struct {
	WechatMsgId       int       `gorm:"primaryKey;column:wechat_listen_record_id;" description:"自增id"`
	Content           string    `description:"监听的微信消息内容"`
	FromWechatId      string    `description:"来源于哪个用户/群的微信标识"`
	FinalFromWechatId string    `description:"群内发言人微信标识"`
	WechatId          string    `description:"消息来源的微信标识；就是当前登录的微信用户"`
	MsgType           int       `description:"消息类型，消息类型；\r\n1 文本消息\r\n3 图片消息\r\n34 语音消息\r\n37 好友确认消息\r\n40 好友推荐消息\r\n42 共享名片\r\n43 视频消息\r\n44 主动撤回\r\n47 动画表情\r\n48 位置消息\r\n49 APP分享链接/文件\r\n50 VOIP消息\r\n51 微信初始化消息 52 VOIP结束消息\r\n53 VOIP邀请\r\n62 小视频\r\n9999 SYSNOTICE\r\n10000 系统消息\r\n10002 撤回消息"`
	Msg               string    `description:"xml消息内容"`
	JumpPath          string    `description:"微信跳转地址"`
	CreateTime        time.Time `description:"发送时间"`
}

func (m *WechatListenMsgRecord) TableName() string {
	return "wechat_listen_msg_record"
}

// Create 添加记录
func (m *WechatListenMsgRecord) Create() (err error) {
	err = global.DEFAULT_MYSQL.Create(m).Error

	return
}

// GetByJumpPath 根据消息类型和跳转地址获取数据
func (m *WechatListenMsgRecord) GetByJumpPath(msgType int, jumpPath string) (item *WechatListenMsgRecord, err error) {
	err = global.DEFAULT_MYSQL.Where(" msg_type = ? AND jump_path = ? ", msgType, jumpPath).
		Order("wechat_listen_record_id DESC").First(&item).Error

	return
}
