package models

import (
	"hongze/hongze_wx_listen/global"
	"time"
)

// WechatMsgPushRecord 推送给微信的消息
type WechatMsgPushRecord struct {
	WechatMsgId         int       `gorm:"primaryKey;column:wechat_msg_id;" description:"消息id"`
	MsgType             int       `description:"消息类型，1：h5链接；2：小程序，3：文字；4：图片"`
	WechatGroupId       int       `description:"微信群id"`
	WechatHelperId      int       `description:"微信小助手id"`
	WechatGroupWechatId string    `description:"微信群/用户所属的微信标识"`
	Title               string    `description:"标题"`
	Content             string    `description:"内容"`
	Pic                 string    `description:"图片地址"`
	JumpUrl             string    `description:"跳转地址"`
	Status              int8      `description:"推送状态，0：未发送，-1：发送失败，1：发送中，2：发送成功，-2：暂停发送"`
	Remark              string    `description:"备注信息"`
	ServerResult        string    `description:"推送结果"`
	ModifyTime          time.Time `description:"修改时间"`
	CreateTime          time.Time `description:"发送时间"`
	SendId              int       `description:"同花顺id"`
	Level               int       `description:"等级，1：紧急，2：优先，3：普通"`
}

func (m *WechatMsgPushRecord) TableName() string {
	return "wechat_msg_push_record"
}

// GetNoPushListByHelperId 根据小助手id获取未发送的列表
func (m *WechatMsgPushRecord) GetNoPushListByHelperId(helperId, size int) (items []*WechatMsgPushRecord, err error) {
	err = global.DEFAULT_MYSQL.Where(" status = 0 AND wechat_helper_id = ? ", helperId).Limit(size).
		Order("wechat_msg_id asc").Find(&items).Error

	return
}

// WechatMsgPushRecordItem 推送给微信的消息
type WechatMsgPushRecordItem struct {
	WechatMsgId         int       `gorm:"primaryKey;column:wechat_msg_id;" description:"消息id"`
	MsgType             int       `description:"消息类型，1：h5链接；2：小程序，3：文字；4：图片"`
	WechatGroupId       int       `description:"微信群id"`
	WechatHelperId      int       `description:"微信小助手id"`
	WechatGroupWechatId string    `description:"微信群/用户所属的微信标识"`
	Title               string    `description:"标题"`
	Content             string    `description:"内容"`
	Pic                 string    `description:"图片地址"`
	JumpUrl             string    `description:"跳转地址"`
	Status              int8      `description:"推送状态，0：未发送，-1：发送失败，1：发送中，2：发送成功"`
	Remark              string    `description:"备注信息"`
	ServerResult        string    `description:"推送结果"`
	ModifyTime          time.Time `description:"修改时间"`
	CreateTime          time.Time `description:"发送时间"`
	SendId              int       `description:"同花顺id"`
}

// GetNoPushListByHelperIdV2 获取研究报告章节详情
func (m *WechatMsgPushRecord) GetNoPushListByHelperIdV2(helperId, size int) (items []*WechatMsgPushRecordItem, err error) {
	//	sql := `select a.*,b.wechat_helper_id
	//FROM wechat_msg_push_record AS a
	//inner join wechat_group_helper_relation AS b  on a.wechat_group_id = b.wechat_group_id
	//WHERE status = 0 AND b.wechat_helper_id = ? limit ?`

	sql := `select a.wechat_msg_id,a.msg_type,a.wechat_group_id,a.wechat_group_wechat_id,a.title,a.content,a.pic,a.jump_url,a.status,a.remark,a.server_result,a.modify_time,a.create_time,a.send_id,b.wechat_helper_id
FROM wechat_msg_push_record AS a
inner join wechat_group_helper_relation AS b  on a.wechat_group_id = b.wechat_group_id
WHERE A.status = 0 AND b.wechat_helper_id = ? order by a.level ASC,a.wechat_msg_id ASC limit ?;`

	err = global.DEFAULT_MYSQL.Raw(sql, helperId, size).Scan(&items).Error
	return
}

// Update 更新对应字段数据
func (m *WechatMsgPushRecord) Update(updateCols []string) (err error) {
	err = global.DEFAULT_MYSQL.Model(m).Select(updateCols).Updates(*m).Error

	return
}

// UpdateV2 更新对应字段数据
func (m *WechatMsgPushRecord) UpdateV2(id, wechatHelperId int, status int8, remark, serverResult string) (err error) {
	sql := `UPDATE wechat_msg_push_record SET wechat_helper_id =? ,status = ?,remark = ?,server_result=?,modify_time=? WHERE wechat_msg_id  = ? `
	err = global.DEFAULT_MYSQL.Exec(sql, wechatHelperId, status, remark, serverResult, time.Now(), id).Error

	return
}

// MultiUpdateStatus 批量修改
func (m *WechatMsgPushRecord) MultiUpdateStatus(idList []int) (err error) {
	sql := `UPDATE wechat_msg_push_record SET status = 1 WHERE wechat_msg_id in (?) `
	err = global.DEFAULT_MYSQL.Exec(sql, idList).Error

	return
}

// CreateList 批量添加入库
func (m *WechatMsgPushRecord) CreateList(list []WechatMsgPushRecord) (err error) {
	err = global.DEFAULT_MYSQL.Create(list).Error

	return
}

// StopTimeOutRecord 暂停超时未发送的记录
func (m *WechatMsgPushRecord) StopTimeOutRecord(day int) (err error) {
	sql := `UPDATE wechat_msg_push_record SET status = -2,remark = ? ,modify_time=? WHERE status  = 0 and create_time <=?`
	err = global.DEFAULT_MYSQL.Exec(sql, `超时未发送`, time.Now(), time.Now().Add(time.Duration(-24*day)*time.Hour)).Error

	return
}
