package task

import (
	"fmt"
	"github.com/tealeg/xlsx"
	"hongze/hongze_wx_listen/models"
	"hongze/hongze_wx_listen/utils"
	"strings"
	"time"
)

// AddMsgPushRecord 定时生成待发送记录
func AddMsgPushRecord() {
	//fmt.Println("start task")
	errMsgList := make([]string, 0)
	defer func() {
		if len(errMsgList) > 0 {
			fmt.Println("定时发送消息失败：")
			for _, errMsg := range errMsgList {
				fmt.Println(errMsg)
			}
		}
	}()
	wechatGroupTagObj := models.WechatGroupTag{}
	wechatGroupObj := models.WechatGroup{}
	wechatMsgPushRecordObj := models.WechatMsgPushRecord{}

	reportSendThsDetailObj := models.ReportSendThsDetail{}
	list, err := reportSendThsDetailObj.GetNoRecordList()
	if err != nil {
		fmt.Println("获取同花顺数据失败,err:", err)
		return
	}

	wechatListenMsgRecordObj := models.WechatListenMsgRecord{}
	//fmt.Println("开始处理了")
	for _, thsRecord := range list {
		if thsRecord.MsgType == 2 {
			// 如果类型是：小程序
			_, tmpErr := wechatListenMsgRecordObj.GetByJumpPath(models.ListenWxAppType, thsRecord.JumpUrl)
			if tmpErr != nil {
				if tmpErr != utils.ErrNoRow {
					fmt.Println("查询小程序推送首发群记录失败,err:", err.Error())
				}
				continue
			}
		}
		thsRecord.RecordStatus = 1
		err = thsRecord.Update([]string{"RecordStatus"})

		if err != nil {
			fmt.Println("更改同花顺记录失败：", err.Error())
			continue
		}
		labelList := make([]string, 0)
		if thsRecord.LabelStr != `` {
			labelList = strings.Split(thsRecord.LabelStr, ",")
		}
		if len(labelList) <= 0 {
			continue
		}
		wechatGroupTagList, tmpErr := wechatGroupTagObj.GetListByTagNameList(labelList)
		if tmpErr != nil {
			fmt.Println("寻找客户标签失败：", tmpErr.Error())
			continue
		}

		wechatGroupIdList := make([]int, 0)
		for _, wechatGroupTag := range wechatGroupTagList {
			wechatGroupIdList = append(wechatGroupIdList, wechatGroupTag.WechatGroupId)
		}
		if len(wechatGroupIdList) <= 0 {
			continue
		}

		wechatGroupList, tmpErr := wechatGroupObj.GetEnabledListByIdList(wechatGroupIdList)
		if tmpErr != nil {
			fmt.Println("寻找客户失败：", tmpErr.Error())
			continue
		}

		wechatGroupMap := make(map[int]*models.WechatGroup)
		for _, wechatGroup := range wechatGroupList {
			wechatGroupMap[wechatGroup.WechatGroupId] = wechatGroup
		}

		addList := make([]models.WechatMsgPushRecord, 0)
		for _, wechatGroupTag := range wechatGroupTagList {
			wechatGroup, ok := wechatGroupMap[wechatGroupTag.WechatGroupId]
			if !ok {
				continue
			}
			addList = append(addList, models.WechatMsgPushRecord{
				//WechatMsgId:         0,
				MsgType:             thsRecord.MsgType,
				WechatGroupId:       wechatGroupTag.WechatGroupId,
				WechatHelperId:      0,
				WechatGroupWechatId: wechatGroup.WechatId,
				Title:               thsRecord.Title,
				Content:             thsRecord.Content,
				Pic:                 thsRecord.Pic,
				JumpUrl:             thsRecord.JumpUrl,
				Status:              0,
				Remark:              "",
				ServerResult:        "",
				ModifyTime:          time.Now(),
				CreateTime:          time.Now(),
				SendId:              thsRecord.SendId,
				Level:               thsRecord.Level,
			})

		}
		if len(addList) > 0 {
			err = wechatMsgPushRecordObj.CreateList(addList)
			if err != nil {
				fmt.Println("添加入库失败")
				continue
			}
		}
	}

}

// StopMsgPushRecord 超时未发送的消息需要停止
func StopMsgPushRecord() {
	wechatMsgPushRecordObj := models.WechatMsgPushRecord{}

	day := 2
	err := wechatMsgPushRecordObj.StopTimeOutRecord(day)
	if err != nil {
		fmt.Println("获取同花顺数据失败,err:", err)
		return
	}

	return
}

func A() {
	path := `C:\Users\123\Desktop\标签.xlsx`
	xlFile, err := xlsx.OpenFile(path)
	if err != nil {
		fmt.Println(err.Error())
		return
	}

	type tmp struct {
		Name   string
		WxId   string
		Label  string
		Helper []string
	}
	wxGroup := make(map[string]tmp)
	helperMap := make(map[string]string)
	// 遍历sheet页读取
	for _, sheet := range xlFile.Sheets {
		fmt.Println("sheet name: ", sheet.Name)
		//遍历行读取
		maxRow := sheet.MaxRow
		fmt.Println("maxRow:", maxRow)
		fmt.Println("maxRow")
		for i := 0; i < maxRow; i++ {

			if i == 0 {
				continue
			}
			row := sheet.Row(i)
			//fmt.Println(row)
			cells := row.Cells

			name := cells[1].Value
			wxId := cells[2].Value
			label := cells[3].Value
			helper := cells[4].Value

			if _, ok := helperMap[helper]; !ok {
				helperMap[helper] = helper
			}

			if wxId == `` {
				continue
			}
			tmpData, ok := wxGroup[wxId]
			var tmpHelper []string
			if !ok {
				tmpHelper = make([]string, 0)
				tmpData = tmp{
					Name:   name,
					WxId:   wxId,
					Label:  label,
					Helper: tmpHelper,
				}
			} else {
				tmpHelper = tmpData.Helper
			}
			tmpHelper = append(tmpHelper, helper)
			tmpData.Helper = tmpHelper
			wxGroup[wxId] = tmpData
			//fmt.Println(name)
			//fmt.Println(wxId)
			//fmt.Println(label)
			//fmt.Println(helper)
			//return

			//if i == 1 {
			//	row := sheet.Row(i)
			//	cells := row.Cells
			//
			//	templateFail := false
			//	if cells[0].Value != "品种分类" {
			//		templateFail = true
			//	}
			//	if cells[1].Value != "录入日期" {
			//		templateFail = true
			//	}
			//	if cells[2].Value != "指标名称" {
			//		templateFail = true
			//	}
			//	if cells[3].Value != "值" {
			//		templateFail = true
			//	}
			//	if cells[4].Value != "频度" {
			//		templateFail = true
			//	}
			//	if cells[5].Value != "单位" {
			//		templateFail = true
			//	}
			//	if templateFail {
			//		br.ErrMsg = "导入文件异常，请下载最新导入模板文件"
			//		br.Msg = "导入文件异常，请下载最新导入模板文件"
			//		return
			//	}
			//}
			//
			//if i > 1 {
			//	row := sheet.Row(i)
			//	cells := row.Cells
			//	if len(cells) >= 6 {
			//		classifyName := cells[0].Value //分类
			//		if classifyName == "" {        //过滤空白行
			//			continue
			//		}
			//		cell1 := cells[1].Value
			//		//createDate := utils.ConvertToFormatDay(cell1) //录入日期
			//		createDate := cell1
			//		cell2 := cells[2].Value //指标名称
			//		secName := strings.Trim(cell2, " ")
			//		frequency := cells[4].Value //频度
			//		unit := cells[5].Value      //单位
			//
			//		closeVal := cells[3].Value //值
			//		if strings.Contains(closeVal, "#N/A") {
			//			continue
			//		}
			//		closeValFloat, err := cells[3].Float() //值
			//
			//		if err != nil {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = cells[3].Value
			//			failItem.Remark = "值类型异常"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			continue
			//		}
			//		newDecimal := decimal.NewFromFloat(closeValFloat)
			//		newDecimal.Round(4)
			//		closeVal = newDecimal.String()
			//		if strings.Contains(closeVal, "#N/A") {
			//			continue
			//		}
			//		//closeVal := closeValFloat.
			//
			//		//判断指标，类型，等数据是否正常
			//		classifyName = strings.Trim(classifyName, " ")
			//		frequency = utils.TrimStr(frequency)
			//		unit = utils.TrimStr(unit)
			//
			//		// 成功数量超过20个指标，那就不导入了
			//		if len(targetMap) >= 150 {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "导入指标数量过多"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//			continue
			//		}
			//
			//		if !strings.Contains(strings.Join(classifyNameStrList, ","), classifyName) {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "没有该品种分类权限"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			continue
			//		}
			//		//fmt.Println(classifyName, createDate, secName, closeVal)
			//
			//		//校验表格中的日期格式
			//		if strings.Contains(createDate, "-") {
			//			//如果是带有 - 的普通日期格式文本
			//			_, timeErr := time.Parse("2006-1-2", createDate)
			//			if timeErr != nil {
			//				failItem := new(models.EdbdataImportFail)
			//				failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//				failItem.ClassifyName = classifyName
			//				failItem.CreateDate = createDate
			//				failItem.SecName = secName
			//				failItem.Close = closeVal
			//				failItem.Remark = "日期格式异常"
			//				failItem.Frequency = frequency
			//				failItem.Unit = unit
			//				failDatas = append(failDatas, failItem)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//				continue
			//			}
			//		} else if strings.Contains(createDate, "/") {
			//			//如果是带有 / 的普通日期格式文本
			//			createDateTime, timeErr := time.Parse("2006/1/2", createDate)
			//			if timeErr != nil {
			//				failItem := new(models.EdbdataImportFail)
			//				failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//				failItem.ClassifyName = classifyName
			//				failItem.CreateDate = createDate
			//				failItem.SecName = secName
			//				failItem.Close = closeVal
			//				failItem.Remark = "日期格式异常"
			//				failItem.Frequency = frequency
			//				failItem.Unit = unit
			//				failDatas = append(failDatas, failItem)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//				continue
			//			}
			//			createDate = createDateTime.Format("2006-01-02")
			//		} else {
			//			//可能是excel的日期格式
			//			_, tmpErr := strconv.Atoi(createDate)
			//			if tmpErr != nil {
			//				failItem := new(models.EdbdataImportFail)
			//				failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//				failItem.ClassifyName = classifyName
			//				failItem.CreateDate = createDate
			//				failItem.SecName = secName
			//				failItem.Close = closeVal
			//				failItem.Remark = "日期格式异常"
			//				failItem.Frequency = frequency
			//				failItem.Unit = unit
			//				failDatas = append(failDatas, failItem)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//				continue
			//			}
			//			createDate = utils.ConvertToFormatDay(createDate) //录入日期
			//		}
			//
			//		//获取指标分类信息
			//		classify, ok := edbDataClassifyMap[classifyName]
			//		if !ok {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "指标分类不存在"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//			continue
			//		}
			//
			//		//判断指标是否存在
			//		target, ok := targetMap[secName]
			//		if !ok {
			//			tmpTarget, err := models.GetTargetBySecName(secName)
			//			if err != nil {
			//				//如果是找不到该指标，那么新增指标
			//				if err.Error() == utils.ErrNoRow() {
			//					if frequency == "" {
			//						failItem := new(models.EdbdataImportFail)
			//						failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//						failItem.ClassifyName = classifyName
			//						failItem.CreateDate = createDate
			//						failItem.SecName = secName
			//						failItem.Close = closeVal
			//						failItem.Remark = "新增指标失败，频度字段为空"
			//						failItem.Frequency = frequency
			//						failItem.Unit = unit
			//						failDatas = append(failDatas, failItem)
			//						continue
			//					}
			//					if unit == "" {
			//						failItem := new(models.EdbdataImportFail)
			//						failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//						failItem.ClassifyName = classifyName
			//						failItem.CreateDate = createDate
			//						failItem.SecName = secName
			//						failItem.Close = closeVal
			//						failItem.Remark = "新增指标失败，单位字段为空"
			//						failItem.Frequency = frequency
			//						failItem.Unit = unit
			//						failDatas = append(failDatas, failItem)
			//						continue
			//					}
			//					tmpErr := data.AddEdbInfo(secName, unit, frequency, "", sysUser.Mobile, classify.ClassifyId, sysUser.AdminId)
			//					if tmpErr != nil {
			//						fmt.Println("line 158")
			//						failItem := new(models.EdbdataImportFail)
			//						failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//						failItem.ClassifyName = classifyName
			//						failItem.CreateDate = createDate
			//						failItem.SecName = secName
			//						failItem.Close = closeVal
			//						failItem.Remark = "新增指标失败"
			//						failItem.Frequency = frequency
			//						failItem.Unit = unit
			//						failDatas = append(failDatas, failItem)
			//						continue
			//					}
			//					tmpTarget, tmpErr := models.GetTargetBySecName(secName)
			//					target = tmpTarget
			//					targetMap[secName] = target
			//				} else {
			//					fmt.Println("导入数据 获取指标:Err:" + err.Error())
			//				}
			//			} else {
			//				target = tmpTarget
			//				targetMap[secName] = target
			//			}
			//
			//			//设置10分钟缓存，不允许其他地方删除
			//			key := "import:edbinfo:data:" + target.TradeCode
			//			utils.Rc.SetNX(key, 1, time.Second*600)
			//		}
			//
			//		if target == nil {
			//			fmt.Println("指标不存在")
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "指标不存在"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			continue
			//		}
			//
			//		//更新指标信息
			//		updateCols := make([]string, 0)
			//		//更新指标分类
			//		if target.ClassifyId <= 0 && classify.ClassifyId > 0 {
			//			target.ClassifyId = classify.ClassifyId
			//			updateCols = append(updateCols, "ClassifyId")
			//		}
			//		if target.Frequency != frequency {
			//			target.Frequency = frequency
			//			target.NoticeTime = ""
			//			updateCols = append(updateCols, "Frequency", "NoticeTime")
			//		}
			//		if target.Unit != unit {
			//			target.Unit = unit
			//			updateCols = append(updateCols, "Unit")
			//		}
			//		if len(updateCols) > 0 {
			//			_ = target.Update(updateCols)
			//		}
			//
			//		//判断数据是否已经存在
			//		count, err := models.GetTargetsDataCount(target.TradeCode, createDate)
			//		if err != nil {
			//			go alarm_msg.SendAlarmMsg("导入数据 判断数据是否存在失败，Err："+err.Error(), 3)
			//			//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 判断数据是否存在失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//		}
			//		//数据已存在，进行更新操作
			//		if count > 0 {
			//			edbData, err := models.GetTargetsData(target.TradeCode, createDate)
			//			if err != nil {
			//				go alarm_msg.SendAlarmMsg("导入数据 获取指标数据失败，Err："+err.Error(), 3)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取指标数据失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//			}
			//			if edbData != nil {
			//				err = models.ModifyTargetsDataByImport(target.TradeCode, createDate, closeVal)
			//				if err != nil {
			//					go alarm_msg.SendAlarmMsg("导入数据 修改数据失败，Err："+err.Error(), 3)
			//					//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 修改数据失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//				}
			//			}
			//		} else { //数据不存在，进行新增操作
			//			if target.TradeCode != "" && createDate != "" && closeVal != "" {
			//				models.AddTargetsDataByImport(target.TradeCode, createDate, closeVal)
			//				if err != nil {
			//					go alarm_msg.SendAlarmMsg("导入数据 新增数据失败，Err："+err.Error(), 3)
			//					//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 新增数据失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//				}
			//			}
			//		}
			//		successCount++
			//	} else {
			//		//br.ErrMsg = "请填写导入内容"
			//		//br.Msg = "请填写导入内容"
			//		//return
			//	}
			//}
		}
	}

	//wechatGroupList := make([]models.WechatGroup,0)
	wechatGroupObj := models.WechatGroup{}
	wxIdList := make([]string, 0)
	wxIdMap := make(map[string]string)
	for _, v := range wxGroup {
		if _, ok := wxIdMap[v.WxId]; !ok {
			wxIdList = append(wxIdList, v.WxId)
			wxIdMap[v.WxId] = ``
		}
	}

	if len(wxIdList) <= 0 {
		fmt.Println("没有群")
		return
	}

	groupList, err := wechatGroupObj.GetListByWxIdList(wxIdList)
	if err != nil {
		fmt.Println("查找群列表失败，err:", err)
		return
	}

	groupMap := make(map[string]*models.WechatGroup)
	for _, v := range groupList {
		groupMap[v.WechatId] = v
	}

	for _, v := range wxGroup {
		item, ok := groupMap[v.WxId]
		if !ok {
			fmt.Println("找不到该群：", v.Name)
			continue
		}
		if len(v.Helper) > 0 {
			for _, helper := range v.Helper {
				if helper != `弘则FICC小助手17号` {
					continue
				}
				if helperId, ok := helperIdMap[helper]; ok {
					tmpWechatGroupHelperRelation := &models.WechatGroupHelperRelation{
						WechatGroupId:  item.WechatGroupId,
						WechatHelperId: helperId,
					}

					fmt.Println(tmpWechatGroupHelperRelation)
					err = tmpWechatGroupHelperRelation.Create()
					if err != nil {
						fmt.Println(v.WxId, ";", v.Name, ";助手：", helper, "添加关系失败，ERR：", err)
					}
				}
			}
		}
	}
	fmt.Println(wxGroup)

}

func B() {
	path := `C:\Users\123\Desktop\标签.xlsx`
	xlFile, err := xlsx.OpenFile(path)
	if err != nil {
		fmt.Println(err.Error())
		return
	}

	type tmp struct {
		Name   string
		WxId   string
		Label  string
		Helper []string
	}
	wxGroup := make(map[string]tmp)
	helperMap := make(map[string]string)
	// 遍历sheet页读取
	for _, sheet := range xlFile.Sheets {
		fmt.Println("sheet name: ", sheet.Name)
		//遍历行读取
		maxRow := sheet.MaxRow
		fmt.Println("maxRow:", maxRow)
		fmt.Println("maxRow")
		for i := 0; i < maxRow; i++ {

			if i == 0 {
				continue
			}
			row := sheet.Row(i)
			//fmt.Println(row)
			cells := row.Cells

			name := cells[1].Value
			wxId := cells[2].Value
			label := cells[3].Value
			helper := cells[4].Value

			if _, ok := helperMap[helper]; !ok {
				helperMap[helper] = helper
			}

			if wxId == `` {
				continue
			}
			tmpData, ok := wxGroup[wxId]
			var tmpHelper []string
			if !ok {
				tmpHelper = make([]string, 0)
				tmpData = tmp{
					Name:   name,
					WxId:   wxId,
					Label:  label,
					Helper: tmpHelper,
				}
			} else {
				tmpHelper = tmpData.Helper
			}
			tmpHelper = append(tmpHelper, helper)
			tmpData.Helper = tmpHelper
			wxGroup[wxId] = tmpData
			//fmt.Println(name)
			//fmt.Println(wxId)
			//fmt.Println(label)
			//fmt.Println(helper)
			//return

			//if i == 1 {
			//	row := sheet.Row(i)
			//	cells := row.Cells
			//
			//	templateFail := false
			//	if cells[0].Value != "品种分类" {
			//		templateFail = true
			//	}
			//	if cells[1].Value != "录入日期" {
			//		templateFail = true
			//	}
			//	if cells[2].Value != "指标名称" {
			//		templateFail = true
			//	}
			//	if cells[3].Value != "值" {
			//		templateFail = true
			//	}
			//	if cells[4].Value != "频度" {
			//		templateFail = true
			//	}
			//	if cells[5].Value != "单位" {
			//		templateFail = true
			//	}
			//	if templateFail {
			//		br.ErrMsg = "导入文件异常，请下载最新导入模板文件"
			//		br.Msg = "导入文件异常，请下载最新导入模板文件"
			//		return
			//	}
			//}
			//
			//if i > 1 {
			//	row := sheet.Row(i)
			//	cells := row.Cells
			//	if len(cells) >= 6 {
			//		classifyName := cells[0].Value //分类
			//		if classifyName == "" {        //过滤空白行
			//			continue
			//		}
			//		cell1 := cells[1].Value
			//		//createDate := utils.ConvertToFormatDay(cell1) //录入日期
			//		createDate := cell1
			//		cell2 := cells[2].Value //指标名称
			//		secName := strings.Trim(cell2, " ")
			//		frequency := cells[4].Value //频度
			//		unit := cells[5].Value      //单位
			//
			//		closeVal := cells[3].Value //值
			//		if strings.Contains(closeVal, "#N/A") {
			//			continue
			//		}
			//		closeValFloat, err := cells[3].Float() //值
			//
			//		if err != nil {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = cells[3].Value
			//			failItem.Remark = "值类型异常"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			continue
			//		}
			//		newDecimal := decimal.NewFromFloat(closeValFloat)
			//		newDecimal.Round(4)
			//		closeVal = newDecimal.String()
			//		if strings.Contains(closeVal, "#N/A") {
			//			continue
			//		}
			//		//closeVal := closeValFloat.
			//
			//		//判断指标，类型，等数据是否正常
			//		classifyName = strings.Trim(classifyName, " ")
			//		frequency = utils.TrimStr(frequency)
			//		unit = utils.TrimStr(unit)
			//
			//		// 成功数量超过20个指标，那就不导入了
			//		if len(targetMap) >= 150 {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "导入指标数量过多"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//			continue
			//		}
			//
			//		if !strings.Contains(strings.Join(classifyNameStrList, ","), classifyName) {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "没有该品种分类权限"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			continue
			//		}
			//		//fmt.Println(classifyName, createDate, secName, closeVal)
			//
			//		//校验表格中的日期格式
			//		if strings.Contains(createDate, "-") {
			//			//如果是带有 - 的普通日期格式文本
			//			_, timeErr := time.Parse("2006-1-2", createDate)
			//			if timeErr != nil {
			//				failItem := new(models.EdbdataImportFail)
			//				failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//				failItem.ClassifyName = classifyName
			//				failItem.CreateDate = createDate
			//				failItem.SecName = secName
			//				failItem.Close = closeVal
			//				failItem.Remark = "日期格式异常"
			//				failItem.Frequency = frequency
			//				failItem.Unit = unit
			//				failDatas = append(failDatas, failItem)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//				continue
			//			}
			//		} else if strings.Contains(createDate, "/") {
			//			//如果是带有 / 的普通日期格式文本
			//			createDateTime, timeErr := time.Parse("2006/1/2", createDate)
			//			if timeErr != nil {
			//				failItem := new(models.EdbdataImportFail)
			//				failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//				failItem.ClassifyName = classifyName
			//				failItem.CreateDate = createDate
			//				failItem.SecName = secName
			//				failItem.Close = closeVal
			//				failItem.Remark = "日期格式异常"
			//				failItem.Frequency = frequency
			//				failItem.Unit = unit
			//				failDatas = append(failDatas, failItem)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//				continue
			//			}
			//			createDate = createDateTime.Format("2006-01-02")
			//		} else {
			//			//可能是excel的日期格式
			//			_, tmpErr := strconv.Atoi(createDate)
			//			if tmpErr != nil {
			//				failItem := new(models.EdbdataImportFail)
			//				failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//				failItem.ClassifyName = classifyName
			//				failItem.CreateDate = createDate
			//				failItem.SecName = secName
			//				failItem.Close = closeVal
			//				failItem.Remark = "日期格式异常"
			//				failItem.Frequency = frequency
			//				failItem.Unit = unit
			//				failDatas = append(failDatas, failItem)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//				continue
			//			}
			//			createDate = utils.ConvertToFormatDay(createDate) //录入日期
			//		}
			//
			//		//获取指标分类信息
			//		classify, ok := edbDataClassifyMap[classifyName]
			//		if !ok {
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "指标分类不存在"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取分类:Err:"+err.Error(), utils.EmailSendToUsers)
			//			continue
			//		}
			//
			//		//判断指标是否存在
			//		target, ok := targetMap[secName]
			//		if !ok {
			//			tmpTarget, err := models.GetTargetBySecName(secName)
			//			if err != nil {
			//				//如果是找不到该指标，那么新增指标
			//				if err.Error() == utils.ErrNoRow() {
			//					if frequency == "" {
			//						failItem := new(models.EdbdataImportFail)
			//						failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//						failItem.ClassifyName = classifyName
			//						failItem.CreateDate = createDate
			//						failItem.SecName = secName
			//						failItem.Close = closeVal
			//						failItem.Remark = "新增指标失败，频度字段为空"
			//						failItem.Frequency = frequency
			//						failItem.Unit = unit
			//						failDatas = append(failDatas, failItem)
			//						continue
			//					}
			//					if unit == "" {
			//						failItem := new(models.EdbdataImportFail)
			//						failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//						failItem.ClassifyName = classifyName
			//						failItem.CreateDate = createDate
			//						failItem.SecName = secName
			//						failItem.Close = closeVal
			//						failItem.Remark = "新增指标失败，单位字段为空"
			//						failItem.Frequency = frequency
			//						failItem.Unit = unit
			//						failDatas = append(failDatas, failItem)
			//						continue
			//					}
			//					tmpErr := data.AddEdbInfo(secName, unit, frequency, "", sysUser.Mobile, classify.ClassifyId, sysUser.AdminId)
			//					if tmpErr != nil {
			//						fmt.Println("line 158")
			//						failItem := new(models.EdbdataImportFail)
			//						failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//						failItem.ClassifyName = classifyName
			//						failItem.CreateDate = createDate
			//						failItem.SecName = secName
			//						failItem.Close = closeVal
			//						failItem.Remark = "新增指标失败"
			//						failItem.Frequency = frequency
			//						failItem.Unit = unit
			//						failDatas = append(failDatas, failItem)
			//						continue
			//					}
			//					tmpTarget, tmpErr := models.GetTargetBySecName(secName)
			//					target = tmpTarget
			//					targetMap[secName] = target
			//				} else {
			//					fmt.Println("导入数据 获取指标:Err:" + err.Error())
			//				}
			//			} else {
			//				target = tmpTarget
			//				targetMap[secName] = target
			//			}
			//
			//			//设置10分钟缓存，不允许其他地方删除
			//			key := "import:edbinfo:data:" + target.TradeCode
			//			utils.Rc.SetNX(key, 1, time.Second*600)
			//		}
			//
			//		if target == nil {
			//			fmt.Println("指标不存在")
			//			failItem := new(models.EdbdataImportFail)
			//			failItem.SysUserId = strconv.Itoa(sysUser.AdminId)
			//			failItem.ClassifyName = classifyName
			//			failItem.CreateDate = createDate
			//			failItem.SecName = secName
			//			failItem.Close = closeVal
			//			failItem.Remark = "指标不存在"
			//			failItem.Frequency = frequency
			//			failItem.Unit = unit
			//			failDatas = append(failDatas, failItem)
			//			continue
			//		}
			//
			//		//更新指标信息
			//		updateCols := make([]string, 0)
			//		//更新指标分类
			//		if target.ClassifyId <= 0 && classify.ClassifyId > 0 {
			//			target.ClassifyId = classify.ClassifyId
			//			updateCols = append(updateCols, "ClassifyId")
			//		}
			//		if target.Frequency != frequency {
			//			target.Frequency = frequency
			//			target.NoticeTime = ""
			//			updateCols = append(updateCols, "Frequency", "NoticeTime")
			//		}
			//		if target.Unit != unit {
			//			target.Unit = unit
			//			updateCols = append(updateCols, "Unit")
			//		}
			//		if len(updateCols) > 0 {
			//			_ = target.Update(updateCols)
			//		}
			//
			//		//判断数据是否已经存在
			//		count, err := models.GetTargetsDataCount(target.TradeCode, createDate)
			//		if err != nil {
			//			go alarm_msg.SendAlarmMsg("导入数据 判断数据是否存在失败，Err："+err.Error(), 3)
			//			//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 判断数据是否存在失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//		}
			//		//数据已存在，进行更新操作
			//		if count > 0 {
			//			edbData, err := models.GetTargetsData(target.TradeCode, createDate)
			//			if err != nil {
			//				go alarm_msg.SendAlarmMsg("导入数据 获取指标数据失败，Err："+err.Error(), 3)
			//				//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 获取指标数据失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//			}
			//			if edbData != nil {
			//				err = models.ModifyTargetsDataByImport(target.TradeCode, createDate, closeVal)
			//				if err != nil {
			//					go alarm_msg.SendAlarmMsg("导入数据 修改数据失败，Err："+err.Error(), 3)
			//					//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 修改数据失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//				}
			//			}
			//		} else { //数据不存在，进行新增操作
			//			if target.TradeCode != "" && createDate != "" && closeVal != "" {
			//				models.AddTargetsDataByImport(target.TradeCode, createDate, closeVal)
			//				if err != nil {
			//					go alarm_msg.SendAlarmMsg("导入数据 新增数据失败，Err："+err.Error(), 3)
			//					//go utils.SendEmail(utils.APPNAME+"失败提醒", "导入数据 新增数据失败:Err:"+err.Error(), utils.EmailSendToUsers)
			//				}
			//			}
			//		}
			//		successCount++
			//	} else {
			//		//br.ErrMsg = "请填写导入内容"
			//		//br.Msg = "请填写导入内容"
			//		//return
			//	}
			//}
		}
	}

	//wechatGroupList := make([]models.WechatGroup,0)
	//wechatGroupObj := models.WechatGroup{}
	//for _, v := range wxGroup {
	//	item, tmpErr := wechatGroupObj.GetByWxId(v.WxId)
	//	if tmpErr != nil {
	//		fmt.Println(v.WxId, ";", v.Name, "查找失败，ERR：", err)
	//		continue
	//	}
	//	if len(v.Helper) > 0 {
	//		for _, helper := range v.Helper {
	//			if helper != `弘则FICC小助手17号` {
	//				continue
	//			}
	//			if helperId, ok := helperIdMap[helper]; ok {
	//				tmpWechatGroupHelperRelation := &models.WechatGroupHelperRelation{
	//					WechatGroupId:  item.WechatGroupId,
	//					WechatHelperId: helperId,
	//				}
	//
	//				fmt.Println(tmpWechatGroupHelperRelation)
	//				//err = tmpWechatGroupHelperRelation.Create()
	//				//if err != nil {
	//				//	fmt.Println(v.WxId, ";", v.Name, ";助手：", helper, "添加关系失败，ERR：", err)
	//				//}
	//			}
	//		}
	//	}
	//
	//	//tmpWechatGroup := &models.WechatGroup{
	//	//	WechatGroupId:   0,
	//	//	WechatGroupName: v.Name,
	//	//	WechatId:        v.WxId,
	//	//	ModifyTime:      time.Now(),
	//	//	CreateTime:      time.Now(),
	//	//}
	//	//
	//	//err = tmpWechatGroup.Create()
	//	//if err != nil {
	//	//	global.LOG.Info("添加监听消息失败")
	//	//}
	//	//
	//	//if v.Label == `` {
	//	//	continue
	//	//}
	//	//labelList := strings.Split(v.Label, ",")
	//	//
	//	//for _, label := range labelList {
	//	//	tmpTag := models.WechatGroupTag{
	//	//		WechatGroupId: tmpWechatGroup.WechatGroupId,
	//	//		TagName:       label,
	//	//		ModifyTime:    time.Now(),
	//	//		CreateTime:    time.Now(),
	//	//	}
	//	//	tmpTag.Create()
	//	//}
	//}
	fmt.Println(wxGroup)

	fmt.Println("a")
}

var helperIdMap = map[string]int{
	"弘则FICC小助手16号": 9,
	"弘则FICC小助手18号": 11,
	"弘则FICC小助手1号":  2,
	//"弘则FICC小助手6号":  9,
	//"弘则FICC小助手14号": 9,
	"弘则FICC小助手5号": 8,
	//"弘则FICC小助手9号": 2,
	"弘则FICC小助手7号":  5,
	"弘则FICC小助手3号":  7,
	"弘则FICC小助手15号": 6,
	"弘则FICC小助手2号":  3,
	"弘则FICC小助手8号":  1,
	"弘则FICC小助手17号": 12,
	"弘则FICC小助手4号":  10,
}
